
From: Randy Vinson <rvinson@mvista.com>

The PPC version of pci_iomap seems to be missing a call to ioremap.  This
patch corrects that oversight and has been tested on a IBM PPC750FX Eval
board.

Signed-off-by: Randy Vinson <rvinson@mvista.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/kernel/pci.c |    6 +++++-
 1 files changed, 5 insertions(+), 1 deletion(-)

diff -puN arch/ppc/kernel/pci.c~ppc32-missing-call-to-ioremap-in-pci_iomap arch/ppc/kernel/pci.c
--- 25/arch/ppc/kernel/pci.c~ppc32-missing-call-to-ioremap-in-pci_iomap	2005-01-22 23:55:09.126086504 -0800
+++ 25-akpm/arch/ppc/kernel/pci.c	2005-01-22 23:55:09.131085744 -0800
@@ -1712,7 +1712,11 @@ void __iomem *pci_iomap(struct pci_dev *
 	if (flags & IORESOURCE_IO)
 		return ioport_map(start, len);
 	if (flags & IORESOURCE_MEM)
-		return (void __iomem *) start;
+		/* Not checking IORESOURCE_CACHEABLE because PPC does
+		 * not currently distinguish between ioremap and
+		 * ioremap_nocache.
+		 */
+		return ioremap(start, len);
 	/* What? */
 	return NULL;
 }
_
